beamprofiler.iso.measured\_quantities.max\_power\_density
=========================================================

.. currentmodule:: beamprofiler.iso.measured_quantities

.. autofunction:: max_power_density